Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 21 fields pub NVIC: Nvic, pub SCB: Scb, pub SYSTICK: SysTick, pub ADC580_BIF_NL01: Adc580BifNl01, pub ANAMISC580_NL01: Anamisc580Nl01, pub BLE580_GR01: Ble580Gr01, pub CHIP_VERSION: ChipVersion, pub CRG580_DCDC_NL01: Crg580DcdcNl01, pub CRG580_NL01: Crg580Nl01, pub GPIO580_PORTS_NL01: Gpio580PortsNl01, pub I2C580_NL00: I2C580Nl00, pub KBRD580_NL01: Kbrd580Nl01, pub OTPC580_GR01: Otpc580Gr01, pub QUADEC580_GR01: Quadec580Gr01, pub RISCUTIL580_GPREG_NL01: Riscutil580GpregNl01, pub RISCUTIL580_WDOG_NL00: Riscutil580WdogNl00, pub SPI443_NL00: Spi443Nl00, pub TMR580_NL01: Tmr580Nl01, pub UART1: Uart1, pub UART2: Uart2, pub WKUP580_NL01: Wkup580Nl01,
}
Required for compatibility with RTIC and other frameworks

Fields

NVIC: NvicSCB: ScbSYSTICK: SysTickADC580_BIF_NL01: Adc580BifNl01ANAMISC580_NL01: Anamisc580Nl01BLE580_GR01: Ble580Gr01CHIP_VERSION: ChipVersionCRG580_DCDC_NL01: Crg580DcdcNl01CRG580_NL01: Crg580Nl01GPIO580_PORTS_NL01: Gpio580PortsNl01I2C580_NL00: I2C580Nl00KBRD580_NL01: Kbrd580Nl01OTPC580_GR01: Otpc580Gr01QUADEC580_GR01: Quadec580Gr01RISCUTIL580_GPREG_NL01: Riscutil580GpregNl01RISCUTIL580_WDOG_NL00: Riscutil580WdogNl00SPI443_NL00: Spi443Nl00TMR580_NL01: Tmr580Nl01UART1: Uart1UART2: Uart2WKUP580_NL01: Wkup580Nl01

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks